Imports System
Imports System.Collections.Generic
Imports System.Threading.Tasks
Imports ITHit.WebDAV.Server
Imports ITHit.WebDAV.Server.CalDav
Imports CalDAVServer.FileSystemStorage.AspNet.CalDav

''' <summary>
''' Assists in finding folders that contain calendars and address books.
''' </summary>
Public Class Discovery
    Implements ICalendarDiscovery

    ''' <summary>
    ''' Instance of <see cref="DavContext"/> .
    ''' </summary>
    Private context As DavContext

    Public Sub New(context As DavContext)
        Me.context = context
    End Sub

    ''' <summary>
    ''' Returns list of folders that contain calendars owned by this principal.
    ''' </summary>
    ''' <remarks>This enables calendars discovery owned by current loged-in principal.</remarks>
    Public Async Function GetCalendarHomeSetAsync() As Task(Of IEnumerable(Of IItemCollection)) Implements ICalendarDiscovery.GetCalendarHomeSetAsync
        Dim calendarsUserFolder As String = String.Format("{0}{1}/", CalendarsRootFolder.CalendarsRootFolderPath, context.UserName)
        Return {Await DavFolder.GetFolderAsync(context, calendarsUserFolder)}
    End Function

    ''' <summary>
    ''' Returns <b>true</b> if <b>calendar-home-set</b> feature is enabled, <b>false</b> otherwise.
    ''' </summary>
    ''' <remarks>
    ''' <para>
    ''' In this method you can analyze User-Agent header to find out the client application used for accessing the server
    ''' and enable/disable <b>calendar-home-set</b> feature for specific client. 
    ''' </para>
    ''' <para>
    ''' iOS and OS X does require <b>calendar-home-set</b> feature to be always enabled. On the other hand it may consume extra 
    ''' resources especially with iOS CalDAV client. iOS starts immediate synchronization of all calendars found on the server 
    ''' via home-set request. Typically you will always enable home-set for iOS and OS X CalDAV clients, but may disable it for other clients.
    ''' </para>
    ''' </remarks>
    Public ReadOnly Property CalendarHomeSetEnabled As Boolean Implements ICalendarDiscovery.CalendarHomeSetEnabled
        Get
            Return True
        End Get
    End Property
End Class
